.. _beamforming:
Beamforming
-------------

.. automodule:: lyceanem.electromagnetics.beamforming
    :members: PatternPlot, Steering_Efficiency, directivity_transform, MaximumDirectivityMap, MaximumDirectivityMapDiscrete, WavefrontWeights, EGCWeights
